@@ -106,18 +106,18 @@ def generate_password(length=20, complexity=None):
     return get_rnd_string(length, complexity)
 
 
-def create_dir(*filename):
+def create_dir(*filename, is_file=True):
     filenames = [filename]
     if isinstance(filename, tuple):
         filenames = filename
 
     for f in filenames:
-        if os.path.isfile(f):
+        if is_file:
             d = os.path.dirname(f)
         else:
             d = f
         if not os.path.exists(d):
-            os.makedirs(f, exist_ok=True)
+            os.makedirs(d, exist_ok=True)
 
 
 def check_create_dir(*filename):
